@@ -1,6 +1,6 @@
 package File::Gettext::Schema;
 
-use namespace::sweep;
+use namespace::autoclean;
 
 use Moo;
 use File::DataClass::Constants;
